# Privacy Policy

We collect personal data when you use the service.

## Your rights

You have the right to access, the right to know, the right to deletion,
and the right to portability of your personal data. To submit a data
subject request (DSAR) please email privacy@example.com.

## Do Not Sell / Share My Personal Information

You have the right to opt-out of sale or sharing of your personal
information. Submit an opt-out request via privacy@example.com or the
"Do Not Sell" link in our footer.

## Controller contact

Data Protection Officer: privacy@example.com. Mailing address:
Example Inc., 100 Example Way, Anywhere, USA.
